#R Code for data exploration, analysis and visualisation for the manuscript submitted titled
#"Using web-sourced photographs to examine temporal patterns in sex-specific diet of a highly sexually dimorphic raptor"

#Code as of 12/06/2022

setwd("~/")

library(effects)
library(car)
library(dplyr)
library(ggplot2)
library(emmeans)
library(nnet)
library(gridExtra)

spars <- read.csv("~/sparrowhawk_data.csv", header = TRUE) #load in data set
sparsfem <- subset(spars, sex == "female") #subset by sex
sparsmale <- subset(spars, sex == "male")

spars$season <- factor(spars$season, levels = c("spring", "summer", "autumn", "winter")) #reorder factors in a suitable order
spars$month <- factor(spars$month, levels = c("jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"))
sparsfem$season <- factor(sparsfem$season, levels = c("spring", "summer", "autumn", "winter"))
sparsfem$month <- factor(sparsfem$month, levels = c("jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"))
sparsmale$season <- factor(sparsmale$season, levels = c("spring", "summer", "autumn", "winter"))
sparsmale$month <- factor(sparsmale$month, levels = c("jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"))

glimpse(spars) #ensure resulting dataframes are correctly formatted
glimpse(sparsfem)
glimpse(sparsmale)

#Distribution of seasonal samples by sex
samples_season <- spars %>%
  group_by(season, sex) %>%
  summarise(n = n())

samples_month <- spars %>%
  group_by(month, sex) %>%
  summarise(n = n())

samples_season$season <- factor(samples$season, levels = c("spring", "summer", "autumn", "winter"))
samples_month$month <- factor(samples_month$month, levels = c("jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"))

p1 <- ggplot(samples_season, (aes(fill= sex, y= n, x= season))) + 
  geom_bar(position = "stack", stat="identity") + 
  labs(x = "Season", y = "Number of photographs") +  
  theme_bw()  

p2 <- ggplot(samples_month, (aes(fill= sex, y= n, x= month))) + 
  geom_bar(position = "stack", stat="identity") + 
  labs(x = "Month", y = "Number of photographs") +  
  theme_bw()  

grid.arrange(p1, p2, nrow = 2)

#Distribution of prey mass
hist(spars$prey_mass)

ggplot(spars, aes(x = prey_mass)) +
  geom_histogram(bins = 15) +
  facet_wrap(~sex) + 
  labs(x = "Prey weight (g)", y = "Count") + 
  theme_bw()

#Visualise data between groups (sex)
ggplot(spars, aes(x = season, y = prey_mass, fill = sex)) + 
  geom_boxplot() + 
  facet_wrap(~sex) +
  labs(x = "Season", y = "Mean prey mass (g)") + 
  theme_bw()

ggplot(spars, aes(x = month, y = prey_mass, fill = sex)) + 
  geom_boxplot() + 
  facet_wrap(~sex) +
  labs(x = "Month", y = "Mean prey mass (g)") + 
  theme_bw()

#Changes in prey weight over time using linear models

mod1 <- lm(prey_mass ~ sex + season + sex*season, data = spars) #exploring differences in mean prey mass, by season, between sexes
summary(mod1)
Anova(mod1)
emmeans(mod1, pairwise ~ sex*season)
plot(allEffects(mod1))
means.mod1 <- emmeans(mod1, pairwise ~ sex*season)

#Model without interaction

mod1.no.int <- lm(prey_mass ~ sex + season, data = spars) #exploring differences in mean prey mass, by season, between sexes
summary(mod1.no.int)
Anova(mod1.no.int)
emmeans(mod1.no.int, pairwise ~ season)

#subset by sex because there is no interaction between sex and season

mod1.female <- lm(prey_mass ~ season, data = sparsfem) #exploring differences in mean prey mass, by season
summary(mod1.female)
Anova(mod1.female)
emmeans(mod1.female, pairwise ~ season)
female_prey_weight_means <- emmeans(mod1.female, pairwise ~ season)
plot(allEffects(mod1.female))

mod1.male <- lm(prey_mass ~ season, data = sparsmale) #exploring differences in mean prey mass, by season
summary(mod1.male)
Anova(mod1.male)
emmeans(mod1.male, pairwise ~ season)
male_prey_weight_means <- emmeans(mod1.male, pairwise ~ season)
plot(allEffects(mod1.male))

#Mean prey weight by month

mod2 <- lm(prey_mass ~ sex + month + sex*month, data = spars)
summary(mod2)
Anova(mod2)
emmeans(mod2, pairwise ~ sex*month)
plot(allEffects(mod2))
means.mod2 <- emmeans(mod2, pairwise ~ sex*month)

#subset by sex because there is no interaction between sex and season, keep effects plots

mod2.female <- lm(prey_mass ~ month, data = sparsfem)
summary(mod2.female)
Anova(mod2.female)
emmeans(mod2.female, pairwise ~ month) #use these in plots
female_prey_weight_months <- emmeans(mod2.female, pairwise ~ month)
plot(allEffects(mod2.female))

mod2.male <- lm(prey_mass ~ month, data = sparsmale)
summary(mod2.male)
Anova(mod2.male)
emmeans(mod2.male, pairwise ~ month) #use these in plots
male_prey_weight_months <- emmeans(mod2.male, pairwise ~ month)
plot(allEffects(mod2.male))

#Differences in prey class over time: multinomial log-linear models

multinom.mod1 <- multinom(prey_size_class ~ sex + season + sex*season, Hess = TRUE, data = spars)
summary(multinom.mod1)
Anova(multinom.mod1, type="III")  # type III tests
plot(allEffects(multinom.mod1))
class_means_season <- emmeans(multinom.mod1, pairwise ~ sex*season | prey_size_class, adjust="tukey", mode = "prob")
class_means_season

#Mean prey weights by season
mean_prey_weights_season <- aggregate(prey_mass ~ sex + season, data = spars, FUN = mean)
mean_prey_weights_season <- as.data.frame(mean_prey_weights_season)
mean_prey_weights_season

#Prey size class by season

multinom.mod1.female <- multinom(prey_size_class ~ season, Hess = TRUE, data = sparsfem)
summary(multinom.mod1.female)
Anova(multinom.mod1.female, type="III")  # type III tests
plot(allEffects(multinom.mod1.female))
class_means_season_female <- emmeans(multinom.mod1.female, pairwise ~ season | prey_size_class, adjust="tukey", mode = "prob")
class_means_season_female

multinom.mod1.male <- multinom(prey_size_class ~ season, Hess = TRUE, data = sparsmale)
summary(multinom.mod1.male)
Anova(multinom.mod1.male, type="III")  # type III tests
plot(allEffects(multinom.mod1.male))
class_means_season_male <- emmeans(multinom.mod1.male, pairwise ~ season | prey_size_class, adjust="tukey", mode = "prob")
class_means_season_male

#Prey size class by month

multinom.mod2 <- multinom(prey_size_class ~ sex + month + sex*month, Hess = TRUE, data = spars)
summary(multinom.mod2)
Anova(multinom.mod2, type="III")  # type III tests
plot(allEffects(multinom.mod2))
class_means_month <- emmeans(multinom.mod2, pairwise ~ sex*month | prey_size_class, adjust="tukey", mode = "prob")
class_means_month

#Mean prey weights by month
prey_weights_month <- aggregate(prey_mass ~ sex + month, data = spars, FUN = mean)
prey_weights_month <- as.data.frame(prey_weights_month)
prey_weights_month

#subset by sex, re run and use barplots on second y

multinom.mod2.female <- multinom(prey_size_class ~ month, Hess = TRUE, data = sparsfem)
summary(multinom.mod2.female)
Anova(multinom.mod2.female, type="III")  # type III tests
plot(allEffects(multinom.mod2.female))
class_means_month_female <- emmeans(multinom.mod2.female, pairwise ~ month | prey_size_class, adjust="tukey", mode = "prob")
class_means_month_female

multinom.mod2.male <- multinom(prey_size_class ~ month, Hess = TRUE, data = sparsmale)
summary(multinom.mod2.male)
Anova(multinom.mod2.male, type="III")  # type III tests
plot(allEffects(multinom.mod2.male))
class_means_month_male <- emmeans(multinom.mod2.male, pairwise ~ month | prey_size_class, adjust="tukey", mode = "prob")
class_means_month_male

#Changes in key prey items over time by sex (only identified species included in analyses and manuscript)

#Start by creating binary response variables using the ifelse() function 1 = key prey species, 0 = if not.
#Only prey items/species that represent 5% or greater included (see Methods)
#This is repeated by sex and only by season due to small sample sizes when exploring monthly differences.

#FEMALE
sparsfem$wpigbin <- ifelse(sparsfem$prey_spp == "wood pigeon", 1, 0)
sparsfem$cdovbin <- ifelse(sparsfem$prey_spp == "collared dove", 1, 0)
sparsfem$starbin <- ifelse(sparsfem$prey_spp == "common starling", 1, 0)
sparsfem$rdovbin <- ifelse(sparsfem$prey_spp == "rock dove", 1, 0)
sparsfem$bbirdbin <- ifelse(sparsfem$prey_spp == "eurasian blackbird", 1, 0)
sparsfem$medbbin <- ifelse(sparsfem$prey_spp == "med_bird", 1, 0)

#Female - woodpigeon model

fem_mwoodpig <- glm(wpigbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mwoodpig)
Anova(fem_mwoodpig)
emmeans(fem_mwoodpig, pairwise ~ season)
emmeans(fem_mwoodpig, pairwise ~ season, type = "response") #type = "response" provides the probability, by season.
fem_mwoodpig_contrasts <- emmeans(fem_mwoodpig, pairwise ~ season)
plot(allEffects(fem_mwoodpig))

#Female - collared dove model

fem_mcdov <- glm(cdovbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mcdov)
Anova(fem_mcdov)
emmeans(fem_mcdov, pairwise ~ season)
emmeans(fem_mcdov, pairwise ~ season, type = "response")
fem_mcdov_contrasts <- emmeans(fem_mcdov, pairwise ~ season)
plot(allEffects(fem_mcdov))

#Female - starling model

fem_mstar <- glm(starbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mstar)
Anova(fem_mstar)
emmeans(fem_mstar, pairwise ~ season)
emmeans(fem_mstar, pairwise ~ season, type = "response")
fem_mstar_contrasts <- emmeans(fem_mstar, pairwise ~ season)
plot(allEffects(fem_mstar))

#Female - rock dove model

fem_mrdov <- glm(rdovbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mrdov)
Anova(fem_mrdov)
emmeans(fem_mrdov, pairwise ~ season)
emmeans(fem_mrdov, pairwise ~ season, type = "response")
fem_mrdov_contrasts <- emmeans(fem_mrdov, pairwise ~ season)
plot(allEffects(fem_mrdov))

#Female - blackbird model

fem_mbbird <- glm(bbirdbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mbbird)
Anova(fem_mbbird)
emmeans(fem_mbbird, pairwise ~ season)
bbirdtest <- emmeans(fem_mbbird, pairwise ~ season, type = "reponse")
confint(bbirdtest, type = "response") #This line should work in replace of line 252.
fem_mbbird_contrasts <- emmeans(fem_mbbird, pairwise ~ season)
plot(allEffects(fem_mbbird))

#Female - medium bird model

fem_mmedbird <- glm(medbbin ~ season, data = sparsfem, family=binomial(link="logit")) 
summary(fem_mmedbird)
Anova(fem_mmedbird)
emmeans(fem_mmedbird, pairwise ~ season)
emmeans(fem_mmedbird, pairwise ~ season, type = "response")
plot(allEffects(fem_mmedbird))

#Now repeat for male sparrowhawk.
#MALE

sparsmale$wpigbin <- ifelse(sparsmale$prey_spp == "wood pigeon", 1, 0)
sparsmale$cdovbin <- ifelse(sparsmale$prey_spp == "collared dove", 1, 0)
sparsmale$starbin <- ifelse(sparsmale$prey_spp == "common starling", 1, 0)
sparsmale$bbirdbin <- ifelse(sparsmale$prey_spp == "eurasian blackbird", 1, 0)
sparsmale$hsparbin <- ifelse(sparsmale$prey_spp == "house sparrow", 1, 0)
sparsmale$smallbbin <- ifelse(sparsmale$prey_spp == "small_bird", 1, 0)
sparsmale$goldfbin <- ifelse(sparsmale$prey_spp == "goldfinch", 1, 0)
sparsmale$medbbin <- ifelse(sparsmale$prey_spp == "med_bird", 1, 0)

#Male - wood pigeon model

male_mwoodpig <- glm(wpigbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mwoodpig)
Anova(male_mwoodpig)
emmeans(male_mwoodpig, pairwise ~ season)
emmeans(male_mwoodpig, pairwise ~ season, type = "response")
plot(allEffects(male_mwoodpig))

#Male - collared dove model

male_mcdov <- glm(cdovbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mcdov)
Anova(male_mcdov)
emmeans(male_mcdov, pairwise ~ season)
emmeans(male_mcdov, pairwise ~ season, type = "response")
plot(allEffects(male_mcdov))

#Male - starling model

male_mstar <- glm(starbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mstar)
Anova(male_mstar)
emmeans(male_mstar, pairwise ~ season)
startest <- emmeans(male_mstar, pairwise ~ season, type = "reponse")
confint(startest, type = "response")
plot(allEffects(male_mstar))

#Male - blackbird model

male_mbbird <- glm(bbirdbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mbbird)
Anova(male_mbbird)
emmeans(male_mbbird, pairwise ~ season)
emmeans(male_mbbird, pairwise ~ season, type = "response")
plot(allEffects(male_mbbird))

#Male - house sparrow model

male_mhspar <- glm(hsparbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mhspar)
Anova(male_mhspar)
emmeans(male_mhspar, pairwise ~ season)
emmeans(male_mhspar, pairwise ~ season, type = "response")
plot(allEffects(male_mhspar))

#Male - small bird model

male_msmallb <- glm(smallbbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_msmallb)
Anova(male_msmallb)
emmeans(male_msmallb, pairwise ~ season)
emmeans(male_msmallb, pairwise ~ season, type = "response")
plot(allEffects(male_msmallb))

#Male - goldfinch model

male_mgoldf <- glm(goldfbin ~ season, data = sparsmale, family=binomial(link="logit"))
summary(male_mgoldf)
Anova(male_mgoldf)
emmeans(male_mgoldf, pairwise ~ season)
emmeans(male_mgoldf, pairwise ~ season, type = "response")
plot(allEffects(male_mgoldf))

#Male - medium bird model

male_mmedbird <- glm(medbbin ~ season, data = sparsmale, family=binomial(link="logit")) 
summary(male_mmedbird)
Anova(male_mmedbird)
emmeans(male_mmedbird, pairwise ~ season)
emmeans(male_mmedbird, pairwise ~ season, type = "response")
plot(allEffects(male_mmedbird))

table(sparsfem$rdovbin, sparsfem$season)
table(sparsmale$bbirdbin, sparsmale$season)
table(sparsmale$goldfbin, sparsmale$season)
table(sparsmale$starbin, sparsmale$season)

#FIGURES

key_species <- read.csv("data/key_prey_species.csv", header = TRUE)

glimpse(key_species)

key_species$season <- factor(key_species$season, levels = c("spring", "summer", "autumn", "winter"))
key_species$prey <- factor(key_species$prey, levels = c("woodpigeon", "collared dove", "starling", "blackbird"))

unique_species <- read.csv("data/unique_prey_species.csv", header = TRUE)

glimpse(unique_species)

unique_species$season <- factor(unique_species$season, levels = c("spring", "summer", "autumn", "winter"))
unique_species$prey <- factor(unique_species$prey, levels = c("rock dove", "house sparrow", "goldfinch"))

ggplot(key_species, aes(x = season, y = prob, group = sex, colour = sex)) + 
  geom_point(position = position_dodge(0.5), size = 2.5) + 
  geom_errorbar(aes(x = season, ymin = lcl, ymax = ucl), width = 0.5, position = position_dodge(0.5)) + 
  facet_wrap(~prey) + 
  labs(x = "Season", y = "Probability") + 
  scale_y_continuous(limits = c(0,0.5)) + 
  theme_bw()

ggplot(unique_species, aes(x = season, y = prob, group = sex, colour = sex)) + 
  geom_point(position = position_dodge(0.5), size = 2) + 
  geom_errorbar(aes(x = season, ymin = lcl, ymax = ucl), width = 0.5, position = position_dodge(0.5)) + 
  facet_wrap(~prey) + 
  labs(x = "Season", y = "Probability") + 
  scale_y_continuous(limits = c(0,0.5)) + 
  theme_bw()
